pitcharraytools.make_populated_pitch_array_from_list_of_pitch_lists
===================================================================

.. autofunction:: abjad.tools.pitcharraytools.make_populated_pitch_array_from_list_of_pitch_lists.make_populated_pitch_array_from_list_of_pitch_lists
